searchData={"items":[{"type":"module","title":"SpeechMarkdown","doc":"Elixir implementation for the Speech Markdown format.\n\nhttps://www.speechmarkdown.org/\n\nSpeech Markdown is a text format which is akin to regular Markdown,\nbut with an alternative syntax and built for the purpose of\ngenerating platform-specific\n[SSML](https://en.wikipedia.org/wiki/Speech_Synthesis_Markup_Language)\nmarkup.\n\nThe Speech Markdown transpiler converts the given Speeach Markdown text to the\nSpeech Synthesis Markup Language (SSML) format. The results are\nreturned as an SSML string.\n\nCurrently, SMD → SSML support is available in a general variant, and\nspecific SSML variants for the Amazon Alexa and Google Assistant\nplatforms.","ref":"SpeechMarkdown.html"},{"type":"function","title":"SpeechMarkdown.to_plaintext/1","doc":"Convert the given Speech Markdown into plain text.","ref":"SpeechMarkdown.html#to_plaintext/1"},{"type":"function","title":"SpeechMarkdown.to_plaintext!/1","doc":"","ref":"SpeechMarkdown.html#to_plaintext!/1"},{"type":"function","title":"SpeechMarkdown.to_ssml/2","doc":"Convert the given Speech Markdown into SSML.\n\nOptions:\n\n- `xml_declaration` - boolean to indicate whether we need the XML\n  declaration in the output, default `false`\n\n- `variant` - Which SSML variant to choose from. Either `:general`,\n  `:alexa` or `:google`; defaults to `:general`.\n\n- `validate` - `:strict` (default) or `:loose`; when strict, return\n  error when encountering invalid syntax, unknown attributes or\n  unknown attribute values; when `:loose`, such errors are ignored.","ref":"SpeechMarkdown.html#to_ssml/2"},{"type":"function","title":"SpeechMarkdown.to_ssml!/2","doc":"","ref":"SpeechMarkdown.html#to_ssml!/2"},{"type":"type","title":"SpeechMarkdown.option/0","doc":"","ref":"SpeechMarkdown.html#t:option/0"},{"type":"type","title":"SpeechMarkdown.options/0","doc":"","ref":"SpeechMarkdown.html#t:options/0"},{"type":"exception","title":"SpeechMarkdown.ParseError","doc":"Raised when a Speech Markdown string failes to parse using SpeechMarkdown.to_ssml!/2","ref":"SpeechMarkdown.ParseError.html"},{"type":"function","title":"SpeechMarkdown.ParseError.new/1","doc":"","ref":"SpeechMarkdown.ParseError.html#new/1"},{"type":"extras","title":"SpeechMarkdown","doc":"# SpeechMarkdown\n\n[Speech Markdown](https://www.speechmarkdown.org/) transpiler for Elixir.\n\nThis library converts text in the Speech Markdown format to\n[SSML](https://www.w3.org/TR/speech-synthesis11/) for processing by\nText-To-Speech APIs, etc.","ref":"readme.html"},{"type":"extras","title":"Status - SpeechMarkdown","doc":"[![Hex](http://img.shields.io/hexpm/v/speechmarkdown.svg?style=flat)](https://hex.pm/packages/speechmarkdown)\n[![Test](https://github.com/speechmarkdown/speechmarkdown-ex/actions/workflows/test.yml/badge.svg)](https://github.com/speechmarkdown/speechmarkdown-ex/actions/workflows/test.yml)\n[![Coverage](https://coveralls.io/repos/github/speechmarkdown/speechmarkdown-ex/badge.svg)](https://coveralls.io/github/speechmarkdown/speechmarkdown-ex)\n\nThe API reference is available [here](https://hexdocs.pm/speechmarkdown/).","ref":"readme.html#status"},{"type":"extras","title":"Installation - SpeechMarkdown","doc":"```elixir\ndef deps do\n  [\n    {:speechmarkdown, \"~> 0.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - SpeechMarkdown","doc":"As of version 0.2, the entire Speech Markdown specification is\nsupported and unified over the multiple implementations (JS, Elixir)\nunder a single collection of [reference test cases](https://github.com/speechmarkdown/speechmarkdown-test-files).\n\n```elixir\niex> SpeechMarkdown.to_ssml!(\"You say pecan, I say (pecan)[/pɪˈkɑːn/].\")\n\n\" You say pecan, I say  pecan . \"\n```\n\nThe library supports the `:general`, `:alexa` and `:google` variants\nof SSML. Some Speech Markdown tags are only available on those\nplatforms, e.g. `[whisper]`:\n\n```elixir\niex> SpeechMarkdown.to_ssml!(\"#[whisper] I can see dead people\", variant: :alexa)\n\"  I can see dead people  \"\n```\n\nThe following Speech Markdown modifiers are supported:\n\n- [break](https://www.speechmarkdown.org/syntax/break/)\n- [characters](https://www.speechmarkdown.org/syntax/characters/)\n- [ipa](https://www.speechmarkdown.org/syntax/ipa/)\n- [number](https://www.speechmarkdown.org/syntax/number/)","ref":"readme.html#usage"},{"type":"extras","title":"Extensions to speech markdown - SpeechMarkdown","doc":"The following additional Speech Markdown syntax is supported:\n\n- `$[x]` inserts an [SSML Mark][mark] named `x`\n\n[mark]: https://cloud.google.com/text-to-speech/docs/ssml#mark","ref":"readme.html#extensions-to-speech-markdown"},{"type":"extras","title":"License - SpeechMarkdown","doc":"Copyright 2020 Spokestack, Inc.\nCopyright 2020 Bwisc B.V. (Botsquad).\nCopyright 2021 Voiceworks B.V.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n      http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}